@@ -2,7 +2,7 @@ import csv
 import logging
 
 # declare the logging object
-logger = logging.getLogger("utils").addHandler(logging.NullHandler())
+logger = logging.getLogger("utils")
 
 
 def get_content_type(extension):
